@@ -1,4 +1,4 @@
-/* $Id: gdict-app.c,v 1.55 2002/05/13 11:35:56 gman Exp $ */
+/* $Id: gdict-app.c,v 1.57.2.1 2002/07/25 16:14:25 gman Exp $ */
 /* -*- mode: c; style: k&r; c-basic-offset: 4 -*- */
 
 /*
@@ -200,6 +200,20 @@ void
 gdict_app_do_lookup (gchar *text) 
 {
     gint retval;
+    gchar *word_entry_text;
+    
+    g_return_if_fail (text != NULL);
+    
+    /* If needed update the the word_entry */
+    word_entry_text = gtk_editable_get_chars (GTK_EDITABLE (word_entry), 0, -1);
+    if ((word_entry_text == NULL) || (*word_entry_text == 0) || (strcmp (word_entry_text, text) != 0))
+    {
+        g_strdown (text);
+        gnome_entry_prepend_history (GNOME_ENTRY (gnome_word_entry), 1, text);
+        gtk_entry_set_text (GTK_ENTRY (word_entry), text);
+    }
+
+    g_free (word_entry_text);
 
     if (gdict_pref.smart && is_pattern (text)) {
 	retval = gdict_spell (text, TRUE);
@@ -233,7 +247,7 @@ lookup_defbox (void)
     gtk_signal_emit_by_name (GTK_OBJECT (word_entry), "paste_clipboard");
     text = gtk_editable_get_chars (GTK_EDITABLE (word_entry), 0, -1);
     g_strdown (text);
-    gnome_entry_append_history (GNOME_ENTRY (gnome_word_entry), 1, text);
+    gnome_entry_prepend_history (GNOME_ENTRY (gnome_word_entry), 1, text);
     gdict_app_do_lookup (text);
     if (text)
         g_free (text);
@@ -311,7 +325,7 @@ lookup_button_drag_cb (GtkWidget *widget, GdkDragContext *context, gint x, gint
 	if (text) {
 		g_strdown (text);
 		gtk_entry_set_text (GTK_ENTRY (word_entry), text);
-    		gnome_entry_append_history (GNOME_ENTRY (gnome_word_entry), 1, text);
+    		gnome_entry_prepend_history (GNOME_ENTRY (gnome_word_entry), 1, text);
     		gdict_app_do_lookup (text);
 		g_free (text);
 	}
@@ -551,9 +565,9 @@ preferences_cb (GtkWidget *menuitem, gpointer user_data)
 }
 
 static void
-about_cb (GtkMenuItem *menuitem, gpointer user_data) 
+about_cb (GtkWidget *menuitem, gpointer user_data) 
 {
-    gdict_about();
+    gdict_about(GTK_WINDOW (user_data));
 }
 
 
@@ -732,7 +746,7 @@ static GnomeUIInfo help_menu_uiinfo[] = {
 };
 
 static GnomeUIInfo menubar_uiinfo[] = {
-    { GNOME_APP_UI_SUBTREE_STOCK, N_("_Dictionary"), NULL, 
+    { GNOME_APP_UI_SUBTREE, N_("_Dictionary"), NULL, 
       dictionary_menu_uiinfo, NULL, NULL, (GnomeUIPixmapType) 0, 
       NULL, 0, (GdkModifierType) 0, NULL },
     GNOMEUIINFO_MENU_EDIT_TREE (edit_menu_uiinfo),
@@ -779,7 +793,7 @@ GtkWidget *gdict_app_create (gboolean applet) {
         memcpy (&dictionary_menu_uiinfo[EXIT_FILE_MENU_ITEM],
 		&applet_close_item, sizeof(GnomeUIInfo));
 
-    gnome_app_create_menus (GNOME_APP (gdict_app), menubar_uiinfo); 
+    gnome_app_create_menus_with_data (GNOME_APP (gdict_app), menubar_uiinfo, GTK_WIDGET(gdict_app)); 
     gdict_edit_menu_set_sensitivity (FALSE);  
     
     vbox = gtk_vbox_new (FALSE, 0);
