@@ -1,4 +1,4 @@
-/* $Id: gdict-applet.c,v 1.38 2002/06/03 20:40:13 gman Exp $ */
+/* $Id: gdict-applet.c,v 1.38.2.2 2002/07/24 22:17:11 gman Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -66,8 +66,8 @@ entry_activate_cb (GtkEntry *entry, gpointer data)
         	return;
         
     	g_strdown (text);
+	gtk_editable_delete_text (GTK_EDITABLE (entry), 0, -1);
     	gdict_app_do_lookup (text);
-    	gtk_entry_set_text (GTK_ENTRY (word_entry), text);
     	g_free (text);
  
 
@@ -167,7 +167,27 @@ help_cb (BonoboUIComponent *uic,
           const gchar       *verbname)
 {
 	GError *error = NULL;
-        gnome_help_display("gnome-dictionary",NULL,&error);
+	gnome_help_display("gnome-dictionary",NULL,&error);
+
+	if (error)
+	{
+		GtkWidget *dialog;
+
+		dialog = gtk_message_dialog_new (NULL,
+						 GTK_DIALOG_MODAL,
+						 GTK_MESSAGE_ERROR,
+						 GTK_BUTTONS_CLOSE,
+						 ("There was an error displaying help: \n%s"),
+						 error->message);
+
+		g_signal_connect (G_OBJECT (dialog), "response",
+				  G_CALLBACK (gtk_widget_destroy),
+				  NULL);
+
+		gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+		gtk_widget_show (dialog);
+		g_error_free (error);
+	}
 }
 
 static void
