@@ -45,7 +45,8 @@
 typedef enum {
 	NOT_RUNNING,
 	RUNNING,
-	MAKE_IT_STOP
+	MAKE_IT_STOP,
+	MAKE_IT_QUIT
 } RunLevel;
 
 enum {
@@ -183,9 +184,9 @@ make_find_cmd (const char *start_dir)
 
 	if(start_dir) {
 		escape_dir = g_strescape(start_dir, NULL);
-		g_string_append_printf(cmdbuf, "find \"%s\" %s ", escape_dir, defoptions);
+		g_string_append_printf(cmdbuf, "exec find \"%s\" %s ", escape_dir, defoptions);
 	} else
-		g_string_append_printf(cmdbuf, "find . %s ", defoptions);
+		g_string_append_printf(cmdbuf, "exec find . %s ", defoptions);
 
 	for(list=criteria_find;list!=NULL;list=g_list_next(list)) {
 		FindOption *opt = list->data;
@@ -284,10 +285,10 @@ make_locate_cmd(void)
 
 	if (locate_command != NULL)
 	{
-		g_string_append_printf (cmdbuf, "%s '%s*%s'", locate_command, locale_locate_path,
+		g_string_append_printf (cmdbuf, "exec %s '%s*%s'", locate_command, locale_locate_path,
 					locale_locate_string);
 	} else {
-		g_string_append_printf (cmdbuf, "find \"%s\" -name '%s' -mount", locale_locate_path, 
+		g_string_append_printf (cmdbuf, "exec find \"%s\" -name '%s' -mount", locale_locate_path, 
 					locale_locate_string);
 	}	
 	g_free (locate_path);
@@ -735,6 +736,7 @@ really_run_command(char *cmd, char sepchar, gchar *utf8_pattern_str, RunLevel *r
 					_("Cannot perform the search.\n"
 					"The Bourne shell was not found\n"
 					"It is typically installed as /bin/sh or /usr/bin/sh."));
+				gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (app));
 				gtk_dialog_run (GTK_DIALOG (dialog));
 				gtk_widget_destroy (dialog);
 			}
@@ -798,11 +800,11 @@ really_run_command(char *cmd, char sepchar, gchar *utf8_pattern_str, RunLevel *r
 			fprintf (stderr, "%s", ret);
 		}
 		
-		if (waitpid (-1, NULL, WNOHANG) != 0)
+		if (waitpid (-1, NULL, WNOHANG) == -1)
 			break;
 		if(gtk_events_pending())
 			gtk_main_iteration_do(TRUE);
-		if (*running == MAKE_IT_STOP) {
+		if ((*running == MAKE_IT_STOP) || (*running == MAKE_IT_QUIT)) {
 			kill(pid, SIGKILL);
 			wait(NULL);
 		}
@@ -888,9 +890,17 @@ really_run_command(char *cmd, char sepchar, gchar *utf8_pattern_str, RunLevel *r
 	g_string_free (string, TRUE);
 	g_pattern_spec_free (pattern);
 
-	*running = NOT_RUNNING;
-
-	lock = FALSE;
+	if (*running == MAKE_IT_QUIT)
+	{
+	 	*running = NOT_RUNNING;
+		lock = FALSE;
+		gtk_main_quit ();
+ 	}
+ 	else
+ 	{
+		*running = NOT_RUNNING;
+		lock = FALSE;
+	}
 }
 
 static void
@@ -1179,10 +1189,16 @@ static void
 quit_cb(GtkWidget *w, gpointer data)
 {
 	if(find_running == RUNNING)
-		find_running = MAKE_IT_STOP;
+	{
+		find_running = MAKE_IT_QUIT;
+		return;
+	}
 	if(locate_running == RUNNING)
-		locate_running = MAKE_IT_STOP;
-	gtk_main_quit();
+	{
+		locate_running = MAKE_IT_QUIT;
+		return;
+	}
+	gtk_main_quit ();
 }
 
 static void
@@ -1718,13 +1734,13 @@ stop_search (GtkWidget *w, GdkEventKey *event)
 	{
 		if (locate_running == RUNNING)
 		{
-			buttons = locate_buttons;
-			run_locate_command (buttons[0], buttons);
+			locate_running = MAKE_IT_STOP;
+			return TRUE;
 		}
 		else if (find_running == RUNNING)
 		{
-			buttons = find_buttons;
-			run_command (buttons[0], buttons);
+			find_running = MAKE_IT_STOP;
+			return TRUE;
 		}
 	}
 	return FALSE;
@@ -2011,6 +2027,7 @@ about_cb (GtkWidget *widget, gpointer data)
 		gdk_pixbuf_unref (pixbuf);
 	}
 										
+	gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (data));
 	g_signal_connect (G_OBJECT (about), "destroy",
 			  G_CALLBACK (gtk_widget_destroyed), &about);
 	gtk_widget_show (about);
@@ -2042,7 +2059,7 @@ save_results(GtkFileSelection *selector, gpointer user_data)
 			 GTK_BUTTONS_YES_NO,
 			 _("File %s already exists. Overwrite?"),
 			 filename);
-			 
+		gtk_window_set_transient_for (GTK_WINDOW(dialog), GTK_WINDOW (app));
 		response = gtk_dialog_run (GTK_DIALOG (dialog));
 		
 		gtk_widget_destroy (GTK_WIDGET(dialog));
@@ -2134,7 +2151,8 @@ save_session (GnomeClient *client, gint phase,
 static gint
 die (GnomeClient *client, gpointer client_data)
 {
-	gtk_main_quit ();
+	quit_cb (NULL, NULL);
+	return TRUE;
 }
 
 static GnomeUIInfo search_menu[] = {
@@ -2214,7 +2232,7 @@ main(int argc, char *argv[])
 		      NULL);
 				      
 	/*set up the menu*/
-        gnome_app_create_menus (GNOME_APP (app), gsearch_menu);
+        gnome_app_create_menus_with_data (GNOME_APP (app), gsearch_menu, app);
 	gnome_app_install_menu_hints (GNOME_APP (app), gsearch_menu);
 
 	search = create_window();
